<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */
if ( ! function_exists( 'travel_ultimate_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Travel Ultimate Pro 1.0.0
    */
    function travel_ultimate_pro_add_about_section() {
    	$options = travel_ultimate_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'travel_ultimate_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'travel_ultimate_pro_filter_about_section_details', $section_details );

        $tour_details = array();
        $tour_details = apply_filters( 'travel_ultimate_pro_filter_tour_section_details', $tour_details );

        if ( empty( $section_details ) && empty( $tour_details ) ) {
            return;
        }

        // Render about section now.
        travel_ultimate_pro_render_about_section( $section_details, $tour_details );
    }
endif;

if ( ! function_exists( 'travel_ultimate_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Travel Ultimate Pro 1.0.0
    * @param array $input about section details.
    */
    function travel_ultimate_pro_get_about_section_details( $input ) {
        $options = travel_ultimate_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        =  $options['about_image'] ; 
                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = travel_ultimate_pro_trim_content( 50 );
                    $page_post['url']   = get_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    if ( ! empty( $page_post ) ) {
                        // Push to the main array.
                        array_push( $content, $page_post );
                    }
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'travel_ultimate_pro_filter_about_section_details', 'travel_ultimate_pro_get_about_section_details' );

if ( ! function_exists( 'travel_ultimate_pro_get_tour_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Travel Ultimate Pro 1.0.0
    * @param array $input about section details.
    */
    function travel_ultimate_pro_get_tour_section_details( $input ) {
        $options = travel_ultimate_pro_get_theme_options();
        // Content type.
        $tour_content_type  = $options['tour_content_type'];
        $tour_count = ! empty( $options['tour_count'] ) ? $options['tour_count'] : 7;
        
        $content = array();
        switch ( $tour_content_type ) {
            
            case 'cat':
                $cat = array();
                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_cat_' . $i] ) ){
                        $cat_id = $options['tour_cat_' . $i];
                        $term = get_term( $cat_id, 'category' );
                        if(!is_wp_error( $term ) && $term){
                            $cat['count'] = $term->count;
                            $cat['name'] = $term->name;
                            $cat['url'] = get_term_link( $cat_id, 'category' );
                        
                            if ( ! empty( $cat ) ) {
                                // Push to the main array.
                                array_push( $content, $cat );
                            }
                        }
                    }
                }
            break;

            case 'destination':
                $dest = array();
                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_destinations_' . $i] ) ){
                        $dest_id = $options['tour_destinations_' . $i];
                        $term = get_term( $dest_id, 'travel_locations' );
                        if(!is_wp_error( $term ) && $term){
                            $dest['count'] = $term->count;
                            $dest['name'] = $term->name;
                            $dest['url'] = get_term_link( $dest_id, 'travel_locations' );
    
                            if ( ! empty( $dest ) ) {
                                array_push( $content, $dest );
                            }
                        }
                    }
                }                   
            break;

            case 'trip-types':
                $trip_type = array();
                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_trip_' . $i] ) ){
                        $trip_id = $options['tour_trip_' . $i];
                        $term = get_term( $trip_id, 'itinerary_types' );
                        if(!is_wp_error( $term ) && $term){
                            $trip_type['count'] = $term->count;
                            $trip_type['name'] = $term->name;
                            $trip_type['url'] = get_term_link( $trip_id, 'itinerary_types' );
                            
                            if ( ! empty( $trip_type ) ) {
                                array_push( $content, $trip_type );
                            }
                        }
                      
                    }
                }  
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'travel_ultimate_pro_filter_tour_section_details', 'travel_ultimate_pro_get_tour_section_details' );


if ( ! function_exists( 'travel_ultimate_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Travel Ultimate Pro 1.0.0
   *
   */
   function travel_ultimate_pro_render_about_section( $content_details = array(), $tour_details = array() ) {
        $options = travel_ultimate_pro_get_theme_options();
        $sub_title = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : '';

        if ( empty( $content_details ) && empty( $tour_details ) ) {
            return;
        } 
        ?>

        <?php if ( $options['home_layout'] == 'default-design' ): ?>
        
       <div id="about-us" class="relative page-section" style="background-image: url(<?php echo esc_url( get_template_directory_uri() ) . '/assets/uploads/gray-pattern.png'; ?>);">

            <?php if ( ! empty( $content_details ) ) { ?>
                <div class="wrapper">
                    <?php foreach ( $content_details as $content ) : ?>
                        <div class="header-content-wrapper clear">
                            <div class="section-header">
                                <?php if ( ! empty( $sub_title ) ) : ?>
                                    <span class="section-subtitle"><?php echo esc_html( $sub_title ); ?></span>
                                <?php endif; ?>

                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <h2 class="section-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                <?php endif; ?>
                            </div><!-- .section-header -->

                            <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .section-content -->
                            <?php endif; ?>
                        </div><!-- .header-content-wrapper -->
                    <?php endforeach; ?>
                </div><!-- .wrapper -->
            <?php }; ?>

            <?php if ( ! empty( $tour_details ) ) { 

                $tour_count = count( $tour_details );
                if ( $tour_count <= 3 ) {
                    $class = 'classic';
                } else {
                    $class = 'modern';
                }
                ?>
                <!-- use classes "classic-slider and modern-slider" -->
                <div class="tours-slider <?php echo esc_attr( $class ); ?>-slider" data-slick='{"slidesToShow": 5, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                    <?php 
                    $i = 1;
                    foreach ( $tour_details as $tour ) : 
                        $img = ( ! empty( $options['tour_image_' . $i ] ) ) ? $options['tour_image_' . $i ] : '';
                        ?>
                        <article>
                            <div class="tour-item-wrapper" style="background-image: url('<?php echo esc_url( $img ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title">
                                        <?php if ( ! empty( $tour['name'] ) ) { ?>
                                            <a href="<?php echo esc_url( $tour['url'] ); ?>">
                                                <?php echo esc_html( $tour['name'] ); ?>
                                            </a>
                                        <?php } ?>
                                    </h2>
                                    <?php if ( ! empty( $tour['count'] ) ) { ?>
                                        <span><?php echo absint( $tour['count'] ) . esc_html__( ' Trips', 'travel-ultimate-pro' ); ?></span>
                                    <?php } ?>
                                </header>
                            </div><!-- .tour-item-wrapper -->
                        </article>
                    <?php 
                    $i++;
                    endforeach; ?>
                </div><!-- .tours-slider -->
            <?php } ?>
        </div><!-- #skills -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'sixth-design' ): ?>

        <div id="business-about-us" class="relative page-section">
                <div class="wrapper">

                <?php foreach ( $content_details as $content ) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="#" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="business-read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['about_button'] ); ?></a>
                            </div><!-- .business-read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- #business-about-us -->

    <?php endif; ?>

    <?php
    }
endif;