<?php
/**
 * Latest Product section
 *
 * This is the template for the content of product section
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */
if ( ! function_exists( 'travel_ultimate_pro_add_latest_product_section' ) ) :
    /**
    * Add product section
    *
    *@since Travel Ultimate Pro 1.0.0
    */
    function travel_ultimate_pro_add_latest_product_section() {
    	$options = travel_ultimate_pro_get_theme_options();
        // Check if product is enabled on frontpage
        $latest_product_section_enable = apply_filters( 'travel_ultimate_pro_section_status', true, 'latest_product_section_enable' );

        if ( true !== $latest_product_section_enable ) {
            return false;
        }
        // Get product section details
        $section_details = array();
        $section_details = apply_filters( 'travel_ultimate_pro_filter_latest_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render product section now.
        travel_ultimate_pro_render_latest_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_ultimate_pro_get_latest_product_section_details' ) ) :
    /**
    * product section details.
    *
    * @since Travel Ultimate Pro 1.0.0
    * @param array $input product section details.
    */
    function travel_ultimate_pro_get_latest_product_section_details( $input ) {
        $options = travel_ultimate_pro_get_theme_options();

        // Content type.
        $latest_product_content_type  = $options['latest_product_content_type'];     
        $latest_product_count = ! empty( $options['latest_product_count'] ) ? $options['latest_product_count'] : 4;
        
        
        $content = array();
        $content = array();
        switch ( $latest_product_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_product_count; $i++ ) {
                    if ( ! empty( $options['latest_product_content_product_' . $i] ) )
                        $page_ids[] = $options['latest_product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['latest_product_content_product_category'] ) ? $options['latest_product_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $latest_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travel_ultimate_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product section content details.
add_filter( 'travel_ultimate_pro_filter_latest_product_section_details', 'travel_ultimate_pro_get_latest_product_section_details' );


if ( ! function_exists( 'travel_ultimate_pro_render_latest_product_section' ) ) :
  /**
   * Start product section
   *
   * @return string product content
   * @since Travel Ultimate Pro 1.0.0
   *
   */
   function travel_ultimate_pro_render_latest_product_section( $content_details = array() ) {
        $options = travel_ultimate_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
        <div id="latest-products" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                    <?php if( !empty( $options['latest_product_title']  ) ): ?>
                        <h2 class="shop-section-title"><?php echo esc_html( $options['latest_product_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if( !empty( $options['latest_product_subtitle']  ) ): ?>
                        <p class="shop-subtitle"><?php echo esc_html( $options['latest_product_subtitle'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <ul class="products col-4">
                           
                           <?php foreach ( $content_details as $content ): ?>

                            <li class="product featured-products">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                    <?php 
                                    $product = new WC_Product( $content['id'] );
                                    if ( $product->get_sale_price() ): 
                                        ?>
                                    <span class="onsale">
                                        <?php esc_html_e('Sale!', 'travel-ultimate-pro'); ?>
                                    </span>
                                <?php endif ?>
                                    <img src="<?php echo esc_url( $content['image'] ) ?>">
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    <span class="price">
                                        <ins><span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol">
                                            <?php 
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                            ?>
                                        </span></ins>
                                    </span>
                                </a>
                            </li>
                        <?php endforeach; ?>

                        </ul><!-- .product-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;